<?php # lang_cz.inc.php 1381.1 2009-08-15 10:30:56 VladaAjgl $

/**
 *  @version 1381.1
 *  @author Vladimír Ajgl <vlada@ajgl.cz>
 *  EN-Revision: Revision of lang_en.inc.php
 *  @author Vladimír Ajgl <vlada@ajgl.cz>
 *  @revisionDate 2009/06/14
 *  @author Vladimír Ajgl <vlada@ajgl.cz>
 *  @revisionDate 2009/08/15
 */

@define('PLUGIN_SHOUTBOX_NAME',                 'Výkřičník');
@define('PLUGIN_SHOUTBOX_DELETE',               'Smazat');
@define('PLUGIN_SHOUTBOX_SUBMIT',               'Pošli výkřik do světa');
@define('PLUGIN_SHOUTBOX_BLAHBLAH',             'Zobrazuje okno pro výkřiky, tzn. komentáře, které nejsou poslané ke konkrétnímu příspěvku');
@define('PLUGIN_SHOUTBOX_WORDWRAP',             'Zalamování slov');
@define('PLUGIN_SHOUTBOX_WORDWRAP_BLAHBLAH',    'Po kolika slovech se má výkřik zalomit? (Přednastaveno: 30)');
@define('PLUGIN_SHOUTBOX_MAXCHARS',             'Maximální počet znaků');
@define('PLUGIN_SHOUTBOX_MAXCHARS_BLAHBLAH',    'Kolik znaků z každého příspěvku má být nanejvýš zobrazeno? (Přednastaveno: 120)');
@define('PLUGIN_SHOUTBOX_MAXENTRIES',           'Počet výkřiků');
@define('PLUGIN_SHOUTBOX_MAXENTRIES_BLAHBLAH',  'Kolik posledních výkřiků se má zobrazovat? (Přednastaveno: 15)');
@define('GENERAL_PLUGIN_BOX_COLS',              'Sloupce shoutboxu');
@define('GENERAL_PLUGIN_BOX_COLS_BLAHBLAH',     'Počet sloupců pole pro zadávání výkřiků');
@define('GENERAL_PLUGIN_BOX_ROWS',              'Počet řádek shoutboxu');
@define('GENERAL_PLUGIN_BOX_ROWS_BLAHBLAH',     'Počet řádek pole pro zadávání výkřiků');